@@ -10,7 +10,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.1.9"
+version = "1.2.0"
 global log
 global anon
 anon = "tor"
@@ -385,8 +385,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "3.66.38.117"
-                     port = "10882"
+                     p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+                     ip = p["ip"]
+                     port = p["port"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
@@ -494,8 +495,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "3.66.38.117"
-                     port = "10882"
+                     p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+                     ip = p["ip"]
+                     port = p["port"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
@@ -582,8 +584,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "3.66.38.117"
-                     port = "10882"
+                     p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+                     ip = p["ip"]
+                     port = p["port"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
@@ -670,8 +673,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "3.66.38.117"
-                     port = "10882"
+                     p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+                     ip = p["ip"]
+                     port = p["port"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
@@ -758,8 +762,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "3.66.38.117"
-                     port = "10882"
+                     p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+                     ip = p["ip"]
+                     port = p["port"]
                      proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
